/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

/*

This file is not meant to be included but serves as a library
for the Qt lupdate utility to translate ALSA strings.

*/

static const char * alsa_i18n_strings[] = {

    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Auto Gain Control" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Auto-Mute Mode" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Bass" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Beep" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Capture" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Center" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Channel Mode" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "External Amplifier" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "External Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Ext Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Front" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Front Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Front Mic Boost" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Headphone" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Headphone LFE" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Headphone Center" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Input Source" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Internal Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Int Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Line" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Line Boost" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Loopback Mixing" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Master" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic Boost" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic Boost (+20dB)" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic Select" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "PC Speaker" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Phone" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Rear Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Rear Mic Boost" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Side" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Speaker" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Surround" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Treble" ),
    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Video" ),

    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "1ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "2ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "3ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "4ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "5ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "6ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "7ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "8ch" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Disabled" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Enabled" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Front Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Internal Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Line" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic1" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic2" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic3" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic4" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Phone" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Rear Mic" ),
    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Video" ),

    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Front Left" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Front Right" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Rear Left" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Rear Right" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Front Center" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Woofer" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Side Left" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Side Right" ),
    QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Rear Center" ),

    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "CARD" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "HWDEP" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "MIXER" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "PCM" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "RAWMIDI" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "TIMER" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "SEQUENCER" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_IFace_Name", "Unknown" ),

    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "NONE" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "BOOLEAN" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "INTEGER" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "ENUMERATED" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "BYTES" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "IEC958" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "INTEGER64" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Elem_Type_Name", "Unknown" ),

    QT_TRANSLATE_NOOP ( "ALSA::CTL_Arg_Name", "CARD" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Arg_Name", "SOCKET" ),
    QT_TRANSLATE_NOOP ( "ALSA::CTL_Arg_Name", "CTL" ),

};
